package encryptionproject;

import java.awt.*;
import java.awt.event.*;
import java.util.EventObject;

class EncryptionProjectPanel extends Panel
    implements ActionListener, ItemListener
{

    public EncryptionProjectPanel()
    {
        emCaesar = new EncryptionCaesarMethod();
        emPolyalphabetic = new EncryptionPolyalphabeticMethod();
        emVernam = new EncryptionVernamMethod();
        emColumnar = new EncryptionColumnarMethod();
        emDES = new EncryptionDESMethod();
        emMerkleHellman = new EncryptionMerkleHellmanMethod();
        emRSA = new EncryptionRSAMethod();
        emElGamal = new EncryptionElGamalMethod();
        em = emCaesar;
        setupPanel();
    }

    private void setupPanel()
    {
        setBackground(new Color(192, 192, 192));
        txtMessageText = new TextArea("", 5, 25, 3);
        txtMessageText.setFont(EncryptionProject.MONOSPACE_FONT);
        txtMessageText.setBackground(Color.white);
        txtCipherCodeText = new TextArea("", 5, 50, 3);
        txtCipherCodeText.setFont(EncryptionProject.CODE_FONT);
        txtCipherCodeText.setEditable(false);
        txtCipherCodeText.setBackground(Color.white);
        txtTutorialText = new TutorialDisplay();
        setLayout(new BorderLayout());
        Panel panel = new Panel(new GridLayout(3, 1));
        Panel panel1 = new Panel(new BorderLayout());
        choiceMethods = new Choice();
        choiceMethods.add("Caesar Cipher");
        choiceMethods.add("Polyalphabetic Substitution");
        choiceMethods.add("Vernam Cipher");
        choiceMethods.add("Columnar Transposition");
        choiceMethods.add("Data Encryption Standard (DES)");
        choiceMethods.add("Merkle-Hellman");
        choiceMethods.add("Rivest-Shamir-Adelman (RSA)");
        choiceMethods.add("El Gamal/Digital Signature Algorithm");
        choiceMethods.addItemListener(this);
        Panel panel2 = new Panel(new FlowLayout(0));
        panel2.add(new Label("Encryption Method:"));
        panel2.add(choiceMethods);
        panel1.add(panel2, "North");
        panel2 = new Panel(new FlowLayout(0));
        panel2.add(new Label("Message"));
        panel2.add(txtMessageText);
        panel1.add(panel2, "Center");
        panel.add(panel1);
        pnlOptions = new Panel(new CardLayout());
        pnlOptions.add("Caesar Cipher", emCaesar.getOptionsPanel());
        pnlOptions.add("Polyalphabetic Substitution", emPolyalphabetic.getOptionsPanel());
        pnlOptions.add("Vernam Cipher", emVernam.getOptionsPanel());
        pnlOptions.add("Columnar Transposition", emColumnar.getOptionsPanel());
        pnlOptions.add("Data Encryption Standard (DES)", emDES.getOptionsPanel());
        pnlOptions.add("Merkle-Hellman", emMerkleHellman.getOptionsPanel());
        pnlOptions.add("Rivest-Shamir-Adelman (RSA)", emRSA.getOptionsPanel());
        pnlOptions.add("El Gamal/Digital Signature Algorithm", emElGamal.getOptionsPanel());
        panel.add(pnlOptions);
        panel1 = new Panel(new FlowLayout(0));
        panel1.add(new Label("Cipher Text"));
        panel2 = new Panel(new BorderLayout());
        choiceDisplay = new Choice();
        choiceDisplay.add("ASCII");
        choiceDisplay.add("Hexadecimal");
        choiceDisplay.add("Decimal");
        choiceDisplay.add("Binary");
        choiceDisplay.addItemListener(this);
        panel2.add(choiceDisplay, "North");
        panel2.add(txtCipherCodeText, "Center");
        panel1.add(panel2);
        panel2 = new Panel();
        panel1.add(panel2);
        panel.add(panel1);
        add(panel, "Center");
        panel1 = new Panel();
        butEncrypt = new Button("Encrypt");
        butEncrypt.addActionListener(this);
        panel1.add(butEncrypt);
        add(panel1, "South");
        add(txtTutorialText, "East");
    }

    private String getHexString(String s)
    {
        String s1 = "";
        for(int i = 0; i < s.length(); i++)
        {
            String s2 = Integer.toHexString(s.charAt(i)).toUpperCase();
            if(s2.length() == 1)
                s2 = "0" + s2;
            s1 = s1 + s2 + " ";
        }

        return s1;
    }

    private String getDecimalString(String s)
    {
        String s1 = "";
        for(int i = 0; i < s.length(); i++)
            s1 = s1 + (int)s.charAt(i) + " ";

        return s1;
    }

    private String getBinaryString(String s)
    {
        String s1 = "";
        for(int i = 0; i < s.length(); i++)
        {
            String s2 = Integer.toBinaryString(s.charAt(i));
            for(int j = s2.length(); j < 8; j++)
                s1 = s1 + "0";

            s1 = s1 + s2 + " ";
        }

        return s1;
    }

    private void setCipherText(String s)
    {
        String s1 = "";
        for(int i = 0; i < s.length(); i++)
            if(s.charAt(i) > '\037')
                s1 = s1 + s.charAt(i);
            else
                s1 = s1 + " ";

    }

    public void actionPerformed(ActionEvent actionevent)
    {
        String s = actionevent.getActionCommand();
        if(s.equals("Encrypt"))
        {
            String s1 = txtMessageText.getText();
            strCipherText = em.encrypt(s1, txtTutorialText);
            setCipherText(strCipherText);
            String s2 = choiceDisplay.getSelectedItem();
            if(s2.equals("Decimal"))
                txtCipherCodeText.setText(getDecimalString(strCipherText));
            else
            if(s2.equals("ASCII"))
            {
                txtCipherCodeText.setText(strCipherText);
                txtCipherCodeText.setFont(EncryptionProject.MONOSPACE_FONT);
            } else
            if(s2.equals("Binary"))
            {
                txtCipherCodeText.setText(getBinaryString(strCipherText));
                txtCipherCodeText.setFont(EncryptionProject.CODE_FONT);
            } else
            if(s2.equals("Hexadecimal"))
            {
                txtCipherCodeText.setText(getHexString(strCipherText));
                txtCipherCodeText.setFont(EncryptionProject.CODE_FONT);
            }
        }
    }

    public void itemStateChanged(ItemEvent itemevent)
    {
        if(itemevent.getSource().equals(choiceMethods))
        {
            String s = choiceMethods.getSelectedItem();
            if(s.equals("Caesar Cipher"))
                em = emCaesar;
            else
            if(s.equals("Polyalphabetic Substitution"))
                em = emPolyalphabetic;
            else
            if(s.equals("Vernam Cipher"))
                em = emVernam;
            else
            if(s.equals("Columnar Transposition"))
                em = emColumnar;
            else
            if(s.equals("Data Encryption Standard (DES)"))
                em = emDES;
            else
            if(s.equals("Merkle-Hellman"))
                em = emMerkleHellman;
            else
            if(s.equals("Rivest-Shamir-Adelman (RSA)"))
                em = emRSA;
            else
            if(s.equals("El Gamal/Digital Signature Algorithm"))
                em = emElGamal;
            ((CardLayout)pnlOptions.getLayout()).show(pnlOptions, s);
        }
        if(itemevent.getSource().equals(choiceDisplay))
        {
            String s1 = choiceDisplay.getSelectedItem();
            if(s1.equals("Decimal"))
            {
                txtCipherCodeText.setText(getDecimalString(strCipherText));
                txtCipherCodeText.setFont(EncryptionProject.CODE_FONT);
            } else
            if(s1.equals("Binary"))
            {
                txtCipherCodeText.setText(getBinaryString(strCipherText));
                txtCipherCodeText.setFont(EncryptionProject.CODE_FONT);
            } else
            if(s1.equals("ASCII"))
            {
                txtCipherCodeText.setText(strCipherText);
                txtCipherCodeText.setFont(EncryptionProject.MONOSPACE_FONT);
            } else
            if(s1.equals("Hexadecimal"))
            {
                txtCipherCodeText.setText(getHexString(strCipherText));
                txtCipherCodeText.setFont(EncryptionProject.CODE_FONT);
            }
        }
    }

    public static void main(String args[])
    {
        EncryptionProject encryptionproject = new EncryptionProject();
        Frame frame = new Frame();
        _cls1 _lcls1 = new  Object()     /* anonymous class not found*/ 
    class _anm1 {}

;
        frame.addWindowListener(_lcls1);
        frame.add(encryptionproject);
        frame.setLocation(200, 200);
        frame.pack();
        frame.setVisible(true);
    }

    public static final String BUTENCRYPT_LABEL = "Encrypt";
    public static final String CAESAR_CHOICE = "Caesar Cipher";
    public static final String POLYALPHABETIC_CHOICE = "Polyalphabetic Substitution";
    public static final String VERNAM_CHOICE = "Vernam Cipher";
    public static final String COLUMNAR_CHOICE = "Columnar Transposition";
    public static final String DES_CHOICE = "Data Encryption Standard (DES)";
    public static final String MERKLEHELLMAN_CHOICE = "Merkle-Hellman";
    public static final String RSA_CHOICE = "Rivest-Shamir-Adelman (RSA)";
    public static final String ELGAMAL_CHOICE = "El Gamal/Digital Signature Algorithm";
    public static final String ASCII_CHOICE = "ASCII";
    public static final String BINARY_CHOICE = "Binary";
    public static final String HEX_CHOICE = "Hexadecimal";
    public static final String DECIMAL_CHOICE = "Decimal";
    private TextArea txtMessageText;
    private TextArea txtCipherCodeText;
    private TutorialDisplay txtTutorialText;
    private Button butEncrypt;
    private Choice choiceMethods;
    private Choice choiceDisplay;
    private Panel pnlOptions;
    private String strCipherText;
    private EncryptionMethod em;
    private EncryptionMethod emCaesar;
    private EncryptionMethod emPolyalphabetic;
    private EncryptionMethod emVernam;
    private EncryptionMethod emColumnar;
    private EncryptionMethod emDES;
    private EncryptionMethod emMerkleHellman;
    private EncryptionMethod emRSA;
    private EncryptionMethod emElGamal;
}
